# Google Auth OAuthlib Stubs

***This is in no way affiliated with Google.***

The stubs were written by [cffnpwr](https://github.com/cffnpwr).

## Installation

```sh
poetry add -G dev google-auth-oauthlib-atubs
```
